@@ -15,7 +15,7 @@ class ProducerFactory(object):
         raise NotImplementedError
 
 
-class ComsumerFactory(object):
+class ConsumerFactory(object):
     def __init__(self, mq_type: str, **mq_options):
         pass
 
